@@ -1,3 +1,7 @@
+package App::Syndicator;
+
+our $VERSION = '0.003';
+
 use MooseX::Declare;
 
 class App::Syndicator with (App::Syndicator::Config, 
@@ -7,7 +11,6 @@ class App::Syndicator with (App::Syndicator::Config,
     use App::Syndicator::UI;
     use App::Syndicator::DB;
 
-    our $VERSION = 0.002;
     our $BASE = "$ENV{HOME}/.syndicator";
 
     has +configfile => (
